@@ -58,6 +58,7 @@ class AutoReWrite(object):
 
     def auto_request(seld, payload, api, timeout=600):
         """
+        请求封装
 
         :param api:
         :param payload:
@@ -92,6 +93,107 @@ class AutoReWrite(object):
         api = f"{self.api_host}/predict_paraphrase"
         return self.auto_request(payload, api, timeout)
 
+    def predict_summary(self, payload, timeout=600):
+        """
+        生成摘要
+        示例：
+
+            payload = {"config": {
+            "num_beams": 5,
+            "max_length": 120,
+            "num_return_sequences": 5
+            },"text": ["Prized for his intelligence, herding instinct and working ability, the Border Collie was developed more "
+                   "than a century ago in Britain. "]}
+            out = predict_summary(payload)
+            print(out)
+
+
+        :param payload:
+        :param api:
+        :param timeout:
+        :return:
+        """
+        api = f"{self.api_host}/predict_en_summary"
+        return self.auto_request(payload, api, timeout)
+
+    def auto_summary(self, text):
+        """
+        自动生成摘要，设置了默认参数
+
+        获取最好的一个摘要信息
+
+
+
+        示例：
+            from tkitAutoRewriter import AutoReWrite, SentenceClassification
+            text = "The Border Collie is a British breed of herding dog of medium size. They are descended from landrace sheepdogs once found all over the British Isles, but became standardized in the Anglo-Scottish border region. Presently they are used primarily as working dogs to herd livestock, specifically sheep.[1] The Border Collie is considered a highly intelligent, extremely energetic, acrobatic and athletic dog. They frequently compete with great success in sheepdog trials and a range of dog sports like dog obedience, disc dog, herding and dog agility. They are one of the most intelligent domestic dog breeds.[2] Border Collies continue to be employed in their traditional work of herding livestock throughout the world and are kept as pets."
+            # rewriter = AutoReWrite(api='http://192.168.1.18:3008')
+            rewriter = AutoReWrite(api='http://127.0.0.1:3000')
+            out = rewriter.auto_summary(text)
+            print(out)
+            > {'results': [[{'summary_text': 'Border Collie: Dog Breed Profile, Characteristics, and Development-Worthy of Homeward-Homeward Herding Dogs of the 21st-century Dog-Ages'}]]}
+
+        :param text:
+        :return:
+        """
+        payload = {"config": {
+            "do_sample": False,
+            # "num_beams": 5,
+            "max_length": 256
+            # "num_return_sequences": 5
+        }, "text": [text]}
+        return self.predict_summary(payload, timeout=600)
+        # pass
+
+    def predict_title(self, payload, timeout=600):
+        """
+        生成标题
+
+        示例：
+
+            payload = {"config": {
+            "num_beams": 5,
+            "max_length": 64,
+            "num_return_sequences": 5
+            },"text": ["Prized for his intelligence, herding instinct and working ability, the Border Collie was developed more "
+                   "than a century ago in Britain. "]}
+            out = predict_paraphrase(payload)
+            print(out)
+
+
+        :param payload:
+        :param api:
+        :param timeout:
+        :return:
+        """
+        api = f"{self.api_host}/predict_headline_rewriter"
+        return self.auto_request(payload, api, timeout)
+
+    def auto_title(self, text):
+        """
+        自动生成标题，设置了默认参数
+
+        示例：
+            from tkitAutoRewriter import AutoReWrite, SentenceClassification
+            text = "The Border Collie is a British breed of herding dog of medium size. They are descended from landrace sheepdogs once found all over the British Isles, but became standardized in the Anglo-Scottish border region. Presently they are used primarily as working dogs to herd livestock, specifically sheep.[1] The Border Collie is considered a highly intelligent, extremely energetic, acrobatic and athletic dog. They frequently compete with great success in sheepdog trials and a range of dog sports like dog obedience, disc dog, herding and dog agility. They are one of the most intelligent domestic dog breeds.[2] Border Collies continue to be employed in their traditional work of herding livestock throughout the world and are kept as pets."
+            # rewriter = AutoReWrite(api='http://192.168.1.18:3008')
+            rewriter = AutoReWrite(api='http://127.0.0.1:3000')
+            out = rewriter.auto_title(text)
+            print(out)
+            > {'results': [[{'summary_text': 'Border Collie: Dog Breed Profile, Characteristics, and Development-Worthy of Homeward-Homeward Herding Dogs of the 21st-century Dog-Ages'}]]}
+
+        :param text:
+        :return:
+        """
+        payload = {"config": {
+            # "do_sample": False,
+            "num_beams": 8,
+            "max_length": 64,
+            "num_return_sequences": 8
+        }, "text": [text]}
+        return self.predict_title(payload, timeout=600)
+        pass
+
     def predict_paraphrase_sbert(self, payload, timeout=600):
         """
         预测句子相关性
